#
# spec file for package python-parso
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-parso
Version:        0.8.3
Release:        4.4
Summary:        An autocompletion tool for Python
License:        MIT AND Python-2.0
URL:            https://github.com/davidhalter/parso
Source0:        https://files.pythonhosted.org/packages/source/p/parso/parso-%{version}.tar.gz
Patch1:         https://github.com/davidhalter/parso/commit/cf5969d7a109798adbf9538d70e92138f077d700.patch
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest >= 3.0.7}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildArch:      noarch
%python_subpackages

%description
Parso is a Python parser that supports error recovery and round-trip
parsing for different Python versions (in multiple Python
versions). Parso is also able to list multiple syntax errors in your
python file.

Parso has been battle-tested by jedi. It was pulled out of jedi to be
useful for other projects as well.

Parso consists of a small API to parse Python and analyse the syntax
tree.

%prep
%autosetup -p1 -n parso-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# Python 3.10 has deviating exception messages -- gh#davidhalter/parso#192
python310_args=("-k" "not test_python_exception_matches")
# Python 3.12 also changes how f-strings are parsed
python312_args=("-k" "not test_python_exception_matches")
%pytest "${$python_args[@]}"

%files %{python_files}
%license LICENSE.txt
%doc AUTHORS.txt CHANGELOG.rst README.rst
%{python_sitelib}/parso-%{version}.dist-info
%{python_sitelib}/parso/

%changelog
* Tue Oct  3 2023 Steve Kowalik <steven.kowalik@suse.com>
- Switch to pyproject macros.
- Also skip the recalcitrant test under Python 3.12.
* Fri Apr 21 2023 Dirk Müller <dmueller@suse.com>
- add sle15_python_module_pythons (jsc#PED-68)
* Thu Apr 13 2023 Matej Cepl <mcepl@suse.com>
- Make calling of %%{sle15modernpython} optional.
* Fri Jan  6 2023 Dirk Müller <dmueller@suse.com>
- add cf5969d7a109798adbf9538d70e92138f077d700.patch to fix
  unit tests with Python 3.11/3.12
* Fri Dec 10 2021 Ben Greiner <code@bnavigator.de>
- update to 0.8.3:
  * Add basic support for Python 3.11 and 3.12
- Skip tests failing in Python 3.10 gh#davidhalter/parso#192
* Sun Jun  6 2021 Dirk Müller <dmueller@suse.com>
- update to 0.8.2:
  - Various small bugfixes
* Fri Dec 25 2020 Matej Cepl <mcepl@suse.com>
- update to 0.8.1 (according to gh#davidhalter/jedi#1650 it
  should be compatible with python-jedi now):
  - Dropped Support for Python 2.7, 3.4, 3.5
  - It's possible to use ``pathlib.Path`` objects now in the API
  - The stubs are gone, we are now using annotations
  - ``namedexpr_test`` nodes are now a proper class called ``NamedExpr``
  - A lot of smaller refactorings
* Sat Dec 19 2020 Dirk Müller <dmueller@suse.com>
- update to 0.7.1:
  - Fixed a couple of smaller bugs (mostly syntax error detection in
  ``Grammar.iter_errors``)
* Thu Sep  3 2020 Matej Cepl <mcepl@suse.com>
- Revert back to the 0.7.0 version.
* Tue Apr 14 2020 Benjamin Greiner <code@bnavigator.de>
- update to 0.7.0
  * Fix a lot of annoying bugs in the diff parser. The fuzzer did not find
    issues anymore even after running it for more than 24 hours (500k tests).
  * Small grammar change: suites can now contain newlines even after a newline.
    This should really not matter if you don't use error recovery. It allows for
    nicer error recovery.
- remove py_38.patch (merged upstream)
* Thu Mar  5 2020 Ondřej Súkup <mimi.vx@gmail.com>
- update to 0.6.2
  * Add Grammar.refactor (might still be subject to change until 0.7.0)
  * add py_38.patch - fix tests with py-3.8.2
* Tue Feb  4 2020 Ondřej Súkup <mimi.vx@gmail.com>
- update to 0.6.1
  * Add parso.normalizer.Issue.end_pos to make it possible to know
    where an issue ends
  * Dropped Python 2.6/Python 3.3 support
  * del_stmt names are now considered as a definition (for name.is_definition())
* Fri Dec 27 2019 Ondřej Súkup <mimi.vx@gmail.com>
- update to 0.5.2
  * Add include_setitem to get_definition/is_definition and get_defined_names
  * Fix named expression error listing
  * Fix some f-string tokenizer issues
* Tue Jul 16 2019 Ondřej Súkup <mimi.vx@gmail.com>
- update to 0.5.1
  * Fix: Some unicode identifiers were not correctly tokenized
  * Fix: Line continuations in f-strings are now working
* Tue Jul  2 2019 Marketa Calabkova <mcalabkova@suse.com>
- update to 0.5.0
  * comp_for is now called sync_comp_for for all Python versions to
    be compatible with the Python 3.8 Grammar
  * Added .pyi stubs for a lot of the parso API
  * Small FileIO changes
* Thu Apr 18 2019 Ondřej Súkup <mimi.vx@gmail.com>
- update to 0.4.0
  * Python 3.8 support
  * FileIO support, it's now possible to use abstract file IO, support is alpha
* Thu Feb 14 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.3.4:
  * Fix an f-string tokenizer error
  * Fix async errors in the diff parser
  * A fix in iter_errors
  * 20+ bugfixes in the diff parser and 3 in the tokenizer
  * A fuzzer for the diff parser, to give confidence that the diff parser is in a good shape.
  * Some bugfixes for f-string
* Thu Feb 14 2019 Tomáš Chvátal <tchvatal@suse.com>
- Drop bogus dependency on pytest-cache
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Tue Jul 17 2018 tchvatal@suse.com
- Drop dependency on tox, not really needed
* Thu Jul 12 2018 arun@gmx.de
- specfile:
  * make sure tests are run
- update to version 0.3.1:
  * Bugfixes in the diff parser and keyword-only arguments
* Mon Jul  2 2018 arun@gmx.de
- update to version 0.3.0:
  * Rewrote the pgen2 parser generator.
* Tue Apr 17 2018 arun@gmx.de
- specfile:
  * update copyright year
- update to version 0.2.0:
  * f-strings are now parsed as a part of the normal Python
    grammar. This makes it way easier to deal with them.
* Thu Nov  9 2017 arun@gmx.de
- update to version 0.1.1:
  * Fixed a few bugs in the caching layer
  * Added support for Python 3.7
* Tue Sep 26 2017 arun@gmx.de
- intial version 0.1.0
